function [spctrm,Ea_chla,Ea_chlb,Ea_car] = import_Ea_i_data()

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This script imports Ea_i data (interval: 400-700 nm) from:
%
% % Dauchet, J.; Blanco, S.; Cornet, J.-F.; Fournier, R. (2015): 
% Calculation of the radiative properties of photosynthetic microorganisms. 
% In: Journal of Quantitative Spectroscopy and Radiative Transfer 161, 
% S. 60–84. DOI: 10.1016/j.jqsrt.2015.03.025.
% -> http://edstar.lmd.jussieu.fr/databases
%
% Please do not change the original names of the .txt-files!
% -> "Chlorophyll-a", "Chlorophyll-b" & "Photoprotective-carotenoids"
%
% Inputs:
% none
%
% Outputs:
% spctrm: light spectrum [nm]
% Ea_chla: in vivo absorption coefficient of Chlorophyll a [m²/kg]
% Ea_chlb: in vivo absorption coefficient of Chlorophyll b [m²/kg]
% Ea_car: in vivo absorption coefficient of photoprotective Carotenoids
% [m²/kg]
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[file,path] = uigetfile('*.txt','MultiSelect','on');

if length(file) ~= 3
    error('Please import all 3 files with Ea_i data (Chla, Chlb & photoprot. Car)!');
end

if ~any(contains(file,'-a')) || ~any(contains(file,'-b')) || ~any(contains(file,'protective-car'))
    error('The file name(s) might have been modified or at least one correct file is missing!');
end

Ea_chla_tbl = readtable([path,file{find(contains(file,'-a'))}]);
Ea_chlb_tbl = readtable([path,file{find(contains(file,'-b'))}]);
Ea_car_tbl  = readtable([path,file{find(contains(file,'protective-car'))}]);

spctrm  = Ea_chla_tbl{:,1}(Ea_chla_tbl{:,1} >= 400 & Ea_chla_tbl{:,1} <=700);
Ea_chla = Ea_chla_tbl{:,2}(Ea_chla_tbl{:,1} >= 400 & Ea_chla_tbl{:,1} <=700);
Ea_chlb = Ea_chlb_tbl{:,2}(Ea_chlb_tbl{:,1} >= 400 & Ea_chlb_tbl{:,1} <=700);
Ea_car  = Ea_car_tbl{:,2}(Ea_car_tbl{:,1} >= 400 & Ea_car_tbl{:,1} <=700);