function n_Rubisco = calculate_n_Rubisco_per_RCII(w_chla,w_chlb,M_chla,M_chlb,n_PSU_chl,n_Rubisco_max_bdm)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This script calculates the amount of RuBisCO per RCII under the
% (simplified) assumption that the RuBisCO amount per g bdm remains
% constant.
%
% Inputs:
% w_chla, w_chlb: weight fractions of chla & chlb [g/g]
% M_chla, M_chlb: molecular weights of chla & chlb [g/mol]
% n_PSU_chl: number of chl per photosynthetic unit (PSU) [-]
% n_Rubisco_max: max. amount of RuBisCO per g bdm [1/g]
%
% Outputs:
% n_Rubisco: amount of RuBisCO per RCII [-]
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

n_chla_bdm = w_chla./(M_chla/6.02214086e23);
n_chlb_bdm = w_chlb./(M_chlb/6.02214086e23);

n_PSU_bdm = (n_chla_bdm+n_chlb_bdm)./n_PSU_chl;
n_Rubisco = n_Rubisco_max_bdm./n_PSU_bdm;