function k_PSU_model = estimate_model_param()

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function estimates the values of the model parameters k_RCII,lim &
% k_PSU,lim from experimental PI-curves.
%
% Inputs:
% none required to call this function
% 
% Outputs:
% k_PSU_model: values of k_RCII,lim (1) & k_PSU,lim (2) as a column vector
% [1/s]
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

k0   = [1250;100]; % initial parameter values

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% the parameter bounds were defined according to the data from:
%
% Schulze, P. S. C.; Guerra, R.; Pereira, H.; Schüler, L. M.; 
% Varela, J. C. S. (2017): Flashing LEDs for microalgal production. 
% In: Trends in biotechnology 35 (11), 
% S. 1088–1101. DOI: 10.1016/j.tibtech.2017.07.011.
%
% Wijn, R. de; van Gorkom, H. J. (2001): Kinetics of electron transfer 
% from Q(a) to Q(b) in photosystem II. In: Biochemistry 40 (39), 
% S. 11912–11922. DOI: 10.1021/bi010852r.
%
% Vinyard, D. J.; Ananyev, G. M.; Dismukes, G. C. (2013): 
% Photosystem II: the reaction center of oxygenic photosynthesis. 
% In: Annual review of biochemistry 82, 
% S. 577–606. DOI: 10.1146/annurev-biochem-070511-100425.
%
% and
% 
% Tcherkez, G. G. B.; Farquhar, G. D.; Andrews, T. J. (2006): 
% Despite slow catalysis and confused substrate specificity, all 
% ribulose bisphosphate carboxylases may be nearly perfectly optimized. 
% In: Proceedings of the National Academy of Sciences of the 
% United States of America 103 (19), 
% S. 7246–7251. DOI: 10.1073/pnas.0600605103.

lb_k = [450;35]; % lower parameter bounds
ub_k = [2650;505]; % upper parameter bounds
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

opts        = optimoptions(@fmincon,'Algorithm','interior-point');
fit_problem = createOptimProblem('fmincon','objective',@call_obj_func,'x0',k0,'lb',lb_k,'ub',ub_k,'options',opts);
gs          = GlobalSearch;
k_PSU_model = run(gs,fit_problem);