function x = solve_model_eqsys(k,PMC_PFD_quanta_dzR,sigma_RCII,phi_RCII,n_PQ,n_Rubisco)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This script solves the system of equations of the photosynthesis model.
%
% Inputs:
% k: model parameters k_RCII,lim & k_PSU,lim [1/s]
% PMC_PFD_quanta_dzR: PFD values inside the measuring cell [1/m²/s];
% dim.: [accl. states X set PFD0s X num. of steps along the PBR depth]
% -> in this case: [3x7x20]
% sigma_RCII: PAR-averaged absorption cross-section of the LHCII-RCII
% complex [m²]
% phi_RCII: maximum quantum yield of RCII (corresponds to Fv'/Fm') [-]
% n_PQ: number of PQ-molecules per RCII [-]
% n_Rubisco: amount of RuBisCO per RCII [-]
%
% Outputs:
% x: molar fractions of x_RCII,gs, x_RCII,es, x_PQ,gs & x_PQ,es [-];
% dim.: [accl. states X set PFD0s X num. of steps along the PBR depth X x]
% -> in this case: [3x7x20x4]
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

x0 = [0.5;0.5;0.5;0.5];

% preallocation
x = zeros(1,size(PMC_PFD_quanta_dzR,2),size(PMC_PFD_quanta_dzR,3),length(x0));

for idx1 = 1:size(PMC_PFD_quanta_dzR,2)
    for idx2 = 1:size(PMC_PFD_quanta_dzR,3)
        x(1,idx1,idx2,:) = fsolve(@model_eqsys,x0);
    end
end

    function eq = model_eqsys(x)
        r_abs_tot       = sigma_RCII.*PMC_PFD_quanta_dzR(1,idx1,idx2);
        r_abs_P         = r_abs_tot.*phi_RCII.*x(1);
        r_RCII_etrans   = k(1).*x(2).*x(3).*n_PQ;
        r_PSU_etrans    = (k(2).*n_Rubisco).*x(4);
        
        eq(1) = 1-x(1)-x(2);
        eq(2) = r_RCII_etrans-r_abs_P;
        eq(3) = 1-x(3)-x(4);
        eq(4) = r_PSU_etrans-r_RCII_etrans;
    end
end